# 📋 Mojicopy

Tool to generate emojis from text prompts stored in the clipboard using OpenAI.

## 🔨 Installation

First you need to install the emoget python package

```shell
pip install mojicopy
```

### VSCode Integration

TBD

### IntelliJ Integration

TBD
